CloudWatchWorkerGuard

Struct CloudWatchWorkerGuard 

pub struct CloudWatchWorkerGuard { /* private fields */ }
Guard returned when creating a CloudWatch layer

When this guard is dropped a shutdown signal will be sent to the CloudWatch logging worker to flush logs and stop processing any more logs.

This is used to ensure buffered logs are flushed on panic or graceful shutdown. Use CloudWatchWorkerGuard::shutdown to explicitly wait for completion.

Implementations

Source

impl CloudWatchWorkerGuard

pub async fn shutdown(self)

Trigger a graceful shutdown and wait for the worker to finish draining and flushing queued logs.